@@ -127,7 +127,7 @@ static void verb_HelpAbout_cb (GtkMenuItem * action, gpointer data)
 
   dlg = gtk_about_dialog_new ();
   g_signal_connect (dlg, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-  gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG(dlg), "Atomix");
+  gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG(dlg), _("Atomix"));
   gtk_about_dialog_set_version (GTK_ABOUT_DIALOG(dlg), VERSION);
   gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(dlg), _("A puzzle game about atoms and molecules"));
   gtk_about_dialog_set_website (GTK_ABOUT_DIALOG(dlg), "http://wiki.gnome.org/Apps/Atomix");
@@ -232,7 +232,7 @@ static void controller_handle_action (GameAction action)
     case GAME_STATE_PAUSED:
       if (action == GAME_ACTION_CONTINUE)
 	{
-	  clock_start (CLOCK(app->clock));
+	  clock_resume (CLOCK(app->clock));
 	  board_gtk_show ();
 	  app->state = (undo_exists())?GAME_STATE_RUNNING:GAME_STATE_RUNNING_UNMOVED;
 	}
@@ -318,7 +318,7 @@ static void setup_level (void)
   goal_view_render (app->goal);
 
   /* init clock */
-  clock_set_seconds (CLOCK(app->clock), 0);
+  clock_reset (CLOCK(app->clock));
   clock_start (CLOCK(app->clock));
 
   g_object_unref (env_pf);
@@ -399,7 +399,7 @@ static void game_init ()
   app->level_no = 0;
   app->score = 0;
   clock_set_format (CLOCK(app->clock), "%M:%S");
-  clock_set_seconds (CLOCK(app->clock), 0);
+  clock_reset (CLOCK(app->clock));
 
   /* init the board */
   board_gtk_init (app->theme, GTK_FIXED (app->fi_matrix));
@@ -422,9 +422,7 @@ void game_level_finished (void)
 
 static void calculate_score (void)
 {
-  gint seconds;
-
-  seconds = time (NULL) - CLOCK(app->clock)->seconds;
+  gint seconds = clock_get_elapsed (CLOCK (app->clock));
 
   if (seconds > 300)
     return;
@@ -575,6 +573,7 @@ static AtomixApp *create_gui (void)
 {
   AtomixApp *app;
   gchar *ui_path;
+  gchar *icon_path;
   GtkBuilder *builder;
   GtkWidget *stats_grid;
   GtkWidget *time_label;
@@ -653,15 +652,18 @@ static AtomixApp *create_gui (void)
   app->lb_formula = GTK_WIDGET (gtk_builder_get_object (builder, "formula_value"));
   app->lb_score = GTK_WIDGET (gtk_builder_get_object (builder, "score_value"));
 
-  gtk_window_set_default_icon_from_file (g_build_filename (DATADIR,
-							   "pixmaps",
-							   "atomix-icon.png",
-							   NULL),
+  g_object_unref (builder);
+
+  icon_path = g_build_filename (DATADIR,
+							    "pixmaps",
+							    "atomix-icon.png",
+							    NULL);
+  gtk_window_set_default_icon_from_file (icon_path,
 					 		   NULL);
+  g_free (icon_path);
 
   gtk_widget_show_all (GTK_WIDGET (app->mainwin));
 
-  g_object_unref (builder);
   return app;
 }
 
